pub struct EmailModule {
pub settings_service: Arc<SettingsService>,
pub template_engine: Arc<TemplateEngine>,
pub sender: Arc<EmailSender>,
}Expand description
Email module - main orchestrator for email operations
Fields
settings_service: Arc<SettingsService>template_engine: Arc<TemplateEngine>sender: Arc<EmailSender>Implementations
Sourceimpl EmailModule
impl EmailModule
pub fn new(settings_service: Arc<SettingsService>) -> ClResult<Self>
Sourcepub async fn schedule_email_task(
scheduler: &Scheduler<App>,
settings_service: &SettingsService,
tn_id: TnId,
params: EmailTaskParams,
) -> ClResult<()>
pub async fn schedule_email_task( scheduler: &Scheduler<App>, settings_service: &SettingsService, tn_id: TnId, params: EmailTaskParams, ) -> ClResult<()>
Schedule email for async sending via task system with automatic retries
Uses the scheduler’s built-in RetryPolicy with exponential backoff. Retry configuration is loaded from settings (email.retry_attempts).
Template is rendered at execution time, not scheduling time.
Sourcepub async fn schedule_email_task_with_key(
scheduler: &Scheduler<App>,
settings_service: &SettingsService,
tn_id: TnId,
params: EmailTaskParams,
) -> ClResult<()>
pub async fn schedule_email_task_with_key( scheduler: &Scheduler<App>, settings_service: &SettingsService, tn_id: TnId, params: EmailTaskParams, ) -> ClResult<()>
Schedule email task with optional custom key for deduplication